package de.fraunhofer.iem.dataprovider.kpi.strategy

import de.fraunhofer.iem.dataprovider.kpi.dto.KpiCalculationDto
import de.fraunhofer.iem.dataprovider.kpi.enumeration.KpiKind
import org.junit.jupiter.api.Test

class AggregationKPICalculationStrategyTest {

    private fun getRootKpi(): KpiCalculationDto {
        val processComplianceKPI = KpiCalculationDto(
            kind = KpiKind.PROCESS_COMPLIANCE,
            calculationStrategy = RawValueKPICalculationStrategy(25),
            value = 25,
            isEmpty = false
        )

        val processTransparencyKPI = KpiCalculationDto(
            kind = KpiKind.PROCESS_TRANSPARENCY,
            calculationStrategy = RawValueKPICalculationStrategy(50),
            value = 50,
            isEmpty = false
        )

        val securityKPI = KpiCalculationDto(
            kind = KpiKind.SECURITY,
            calculationStrategy = AggregationKPICalculationStrategy(),
            value = -1,
            isEmpty = true
        )

        val rootKPI = KpiCalculationDto(
            kind = KpiKind.ROOT,
            calculationStrategy = AggregationKPICalculationStrategy(),
        )

        rootKPI.addChildKPI(processTransparencyKPI, 0.25)
        rootKPI.addChildKPI(processComplianceKPI, 0.25)
        rootKPI.addChildKPI(securityKPI, 0.5)

        return rootKPI
    }

    @Test
    fun calculateKPI() {
        val rootKpi = getRootKpi()
        val kpiHierarchyEdgeDtos = rootKpi.getHierarchyEdges()

        val sum = AggregationKPICalculationStrategy().calculateKPI(kpiHierarchyEdgeDtos)
        assert(sum == 37)
    }
}
